bl_info = {
    "name": "Add Exploding Text",
    "author": "Yann Morère",
    "version": (0,1,0),
    "blender": (2, 6, 1),
    "api": 42615,
    "location": "View3D > Tool Shelf",
    "description": "Add a Text mesh with explode animation.",
    "warning": "", # used for warning icon and text in addons panel
    "wiki_url": "http://yann.morere.free.fr",
    "tracker_url": "http://yann.morere.free.fr",
    "category": "Add Mesh"}
 
#define an interface for my module
import bpy
from bpy.props import *
from math import pi
 
#
#Define my text explosion
#
def MyTextExplosion(newText):
    #newText = Text
    if len(newText)==0:
        newText="Explode"
    #create text
    bpy.ops.object.text_add(view_align=False, enter_editmode=False,location=(0, 0, 0), rotation=(0, 0, 0))
    ActiveObject = bpy.context.scene.objects.active
    #centering text
    ActiveObject.data.align='CENTER'
    #extrude text
    ActiveObject.data.extrude=0.1
    #bevel text
    ActiveObject.data.bevel_depth = 0.01
    ActiveObject.data.bevel_resolution = 10
    #rotating text
    #angles are in radians
    #bpy.ops.transform.rotate(value=(pi/2,), axis=(1.0, 0.0, 0.0), constraint_axis=(False, False, False), constraint_orientation='GLOBAL', mirror=False, proportional='DISABLED', proportional_edit_falloff='SMOOTH', proportional_size=1, snap=False, snap_target='CLOSEST', snap_point=(0, 0, 0), snap_align=False, snap_normal=(0, 0, 0), release_confirm=False)
    #second solution
    ActiveObject.rotation_euler[0]=pi/2 #xaxis
    ActiveObject.rotation_euler[1]=0.0  #yaxis
    ActiveObject.rotation_euler[2]=0.0  #zaxis
    #changing text
    bpy.context.scene.objects.active=ActiveObject
    bpy.ops.object.editmode_toggle()
    bpy.ops.font.delete()
    bpy.ops.font.text_insert(text=newText, accent=False)
    bpy.ops.object.editmode_toggle()
    #convert to mesh to apply effect
    bpy.ops.object.convert(target='MESH', keep_original=False)
    #solidify
    bpy.ops.object.modifier_add(type='SOLIDIFY')
    #apply quick explode
    bpy.ops.object.quick_explode(style='EXPLODE', amount=100, frame_duration=50, frame_start=1, frame_end=51, velocity=1, fade=True)
    #modifying Particle System
    #emitfrom
    ActiveObject.particle_systems['ParticleSystem'].settings.emit_from = 'VERT'
    #particle number
    ActiveObject.particle_systems['ParticleSystem'].settings.count=200
    #particle lifetime
    ActiveObject.particle_systems['ParticleSystem'].settings.lifetime=200 # 200 +48 > 150 ;-)z
    # start/end explosion
    ActiveObject.particle_systems['ParticleSystem'].settings.frame_end = 48
    ActiveObject.particle_systems['ParticleSystem'].settings.frame_start = 48
    #explosion power
    ActiveObject.particle_systems['ParticleSystem'].settings.normal_factor=5.5
    #integration method
    ActiveObject.particle_systems['ParticleSystem'].settings.integrator='RK4'#aa'MIDPOINT'
    #size of particles
    ActiveObject.particle_systems['ParticleSystem'].settings.particle_size = 0.1
    #particles time step
    ActiveObject.particle_systems['ParticleSystem'].settings.timestep = 0.02
    #mass of particles
    ActiveObject.particle_systems['ParticleSystem'].settings.mass = 2.0
    ActiveObject.particle_systems['ParticleSystem'].settings.use_multiply_size_mass = True
    #affect an existing material
    #ActiveObject.material_slots[0].material = bpy.data.materials['TextMaterial']
    #solidifiy parameter
    ActiveObject.modifiers['Solidify'].edge_crease_inner=0.01
    ActiveObject.modifiers['Solidify'].thickness = 0.02
 
#
#Store properties in the active scene
#
def initSceneProperties(scn):
    bpy.types.Scene.MyTextExplodeString = bpy.props.StringProperty(name = "Text", description="My Exploding Text", default="Explode")
    #scn['MyTextExplodeString'] = "Explode"
    return
 
initSceneProperties(bpy.context.scene)
#
#Menu in UI region
#
 
class UIPanel(bpy.types.Panel):
    bl_label = 'Add Exploding Text'
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'TOOLS'
 
 
    @classmethod
    def poll(self,context):
        return(bpy.context.mode == 'OBJECT' or bpy.context.mode == 'EDIT_MESH')
 
    def draw(self, context):
        scn = context.scene #get the context, and the data
        layout = self.layout
#        row.label(text="Text to Explode", icon='FONT_DATA')
        layout.prop(scn, "MyTextExplodeString")
        layout.operator("operator.explodingtext")
 
#
# Define operator
#
class ExplodeTextButton(bpy.types.Operator):
    bl_idname = "operator.explodingtext"
    bl_label = "Create Exploding Text"
    bl_options = {'REGISTER','UNDO'}
 
    def execute(self, context):
        scn = context.scene
        MyTextExplosion(bpy.context.scene['MyTextExplodeString'])
        return{"FINISHED"}
 
def register():
    bpy.utils.register_class(ExplodeTextButton)
    bpy.utils.register_class(UIPanel)
 
 
def unregister():
    bpy.utils.unregister_class(ExplodeTextButton)
    bpy.utils.unregister_class(UIPanel)
 
 
if __name__ == '__main__':
    register()
